@@ -256,6 +256,21 @@ string2Int(char *buf, int base, char decimalPoint)
 }
 #endif
 
+/* want floor of result */
+int divInt(int a, int b)
+{
+	if (a >= 0 || a % b == 0)
+		return a / b;
+	return a / b - 1;
+}
+
+int modInt(int a, int b)
+{
+	if (a >= 0 || a % b == 0)
+		return a % b;
+	return a % b + b;
+}
+
 /* Try not to use since this restricts the size of abacus. */
 LONG
 multPower(int m, int x, int n)
