@@ -72,6 +72,7 @@ extern void toggleRomanNumeralsAbacus(AbacusWidget w);
 extern void toggleAncientRomanAbacus(AbacusWidget w);
 extern void toggleLatinAbacus(AbacusWidget w);
 extern void toggleGroupingAbacus(AbacusWidget w);
+extern void togglePlaceOnRailAbacus(AbacusWidget w);
 extern void toggleVerticalAbacus(AbacusWidget w);
 extern void toggleNegativeSignAbacus(AbacusWidget w);
 extern void toggleQuartersAbacus(AbacusWidget w);
@@ -253,7 +254,8 @@ typedef struct _AbacusPart {
 	Position    middleBarHeight, middleBarPositionY, railWidth;
 	Point       frameSize, beadSize;
 	Point       pos, totalSize, delta, offset, pressOffset;
-	Boolean     sign, minusSign, romanNumerals, group, decimalComma;
+	Boolean     sign, minusSign, romanNumerals;
+	Boolean     group, placeOnRail, decimalComma;
 	Boolean     carryAnomaly, carryAnomalySq;
 	Boolean     mono, reverse, focus, vertical;
 	Boolean     script, demo, teach, lee;
